#!/usr/bin/env python3

"""
A program that reads the file `Met_Office_2011_Air_Data.csv`, and
prints the total cost for all the flights and total cost per each company.
"""

import csv

def main():
	fname = "Met_Office_2011_Air_Data.csv"  # Input file; set as a variable for easier modification

	tc = 0  # Total cost
	tcpac = dict()  # Total cost per air carrier
	ml = 0  # Max len(carrier), to ensure pretty print

	with open(fname, mode="rt", encoding="utf8", newline="") as f:
		prices_reader = csv.reader(f, delimiter=",")
		next(prices_reader)  # Skip the header (not necessary, due to exception handler below)
		for row in prices_reader:
			try:
				cost = float(row[3])
			except ValueError:
				# Invalid value in the table, so we skip the row
				continue
			carrier = row[11]

			if carrier in tcpac:
				tcpac[carrier] += cost
			else:
				tcpac[carrier] = cost
				ml = max(ml, len(carrier))
			tc += cost

	print("Total cost per carrier:")
	for carrier, cost in sorted(tcpac.items(), key=lambda x: x[1]):
		print(("  {:<" + str(ml+1) + "} {:9.2f} GBP").format(carrier + ":", cost))
	print("Total cost: {:9.2f} GBP".format(tc))

main()