#!/usr/bin/env python3

"""
A program that reads the file `Met_Office_2011_Air_Data.csv` and
creates the files `single.csv` and `return.csv`,
containing only the data for single and return flights, respectively.

It copies all the data except the `"Ticket Single or Return"` column
and both files are proper CSV files (with headers, and a comma as
the column separator).
"""

import csv
import os

def main():
	fname = "Met_Office_2011_Air_Data.csv"  # Input file
	sname = "single.csv"  # Singles file
	rname = "return.csv"  # Returns file
	odir = "output"  # Output directory

	if not os.path.exists(odir):
		os.mkdir(odir, 0o755)  # Create output directory (0o755 may be omitted)
	sname = os.path.join(odir, sname)
	rname = os.path.join(odir, rname)

	with open(fname, mode="rt", encoding="utf8", newline="") as f,  \
		 open(sname, mode="wt", encoding="utf8", newline="") as fs, \
		 open(rname, mode="wt", encoding="utf8", newline="") as fr: 
		prices_reader = csv.reader(f, delimiter=",")
		single_writer = csv.writer(fs, delimiter=",")
		return_writer = csv.writer(fr, delimiter=",")

		# Handle the header (this can also be done in the first step of the loop)
		header = next(prices_reader)
		del header[5]  # Remove "Ticket Single or Return" column
		single_writer.writerow(header)
		return_writer.writerow(header)

		for row in prices_reader:
			# The next two lines extract the ticket type; they are equivalent to
			# ticket_type = row.pop(5).lower()
			ticket_type = row[5].lower()
			del row[5]

			if ticket_type == "single":
				single_writer.writerow(row)
			elif ticket_type == "return":
				return_writer.writerow(row)
			else:
				# Report invalid data
				print('Wrong ticket type: "{}"'.format(ticket_type))

	print("Done!")  # It's polite to inform the user that the work is done
					# if there is no other output

main()