#!/usr/bin/env python3

"""
A program that reads the file `latestcsvexport.csv`, and prints:
- how many public toilets are there in each of the Australian towns,
- how many of them are there in each of the Australian states,
- of those towns that have a public toilet, which ones have the longest name, and
- of those towns that have a public toilet, which one has the most toilets (and how many),
- how many public toilets are there in total.
"""

import csv

def main():
	fname = "latestcsvexport.csv"  # Input file; set as a variable for easier modification

	towns = dict()  # Total number per a town
	states = dict()  # Total number per a state
	mlt = 0  # Max len(town), to ensure pretty print
	mls = 0  # Max len(state), to ensure pretty print

	def add_to_dict(d, name, ml):
		"""
		Add `name` to the dictionary `d` with the value 1.
		If `d[name]` already exists, just increase the value by 1.
		The function returns the new maximum length (originally given by `ml`).
		"""
		if name in d:
			d[name] += 1
			return ml
		else:
			d[name] = 1
			return max(ml, len(name))

	with open(fname, mode="rt", encoding="utf8", newline="") as f:
		prices_reader = csv.reader(f, delimiter=",")
		next(prices_reader)  # Skip the header (not necessary, due to exception handler below)
		for row in prices_reader:
			mlt = add_to_dict(towns, row[4], mlt)
			mls = add_to_dict(states, row[5], mls)

	cnt = 0
	print("Total toilets per town:")
	# Print towns, sorted by the town name, and count how many toilets are there in total
	for town, num in sorted(towns.items(), key=lambda x: x[0]):
		cnt += num
		print(("  {:<" + str(mlt+1) + "} {:>3}").format(town + ":", num))

	print("Total toilets per state:")
	# Print towns, sorted by the number of toilets descendingly
	for state, num in sorted(states.items(), key=lambda x: x[1], reverse=False):
		print(("  {:<" + str(mls+1) + "} {:>5}").format(state + ":", num))

	print("The town(s) with the longest name:")
	for town, num in sorted(towns.items(), key=lambda x: x[0]):
		if len(town) == mlt:
			print("  {}".format(town))

	# Find a tuple (town, count) describing the town with
	# the biggest number of public toilets
	max_toilets = max(towns.items(), key=lambda x: x[1])
	print("A town with the maximum number of toilets, {1} in total, is {0}.".format(*max_toilets))
	# or
	#print("The maximum number of public toilets, {0[1]} in total, is in {0[0]}.".format(max_toilets))
	#print("The maximum number of public toilets, {} in total, is in {}.".format(max_toilets[1], max_toilets[0]))

	print("The total number of public toilets in Australia:", cnt)

main()